[llvm-commits] CVS: llvm-java/include/llvm/Java/BytecodeParser.h

Alkis Evlogimenos alkis at cs.uiuc.edu
Mon Oct 18 09:23:13 PDT 2004



Changes in directory llvm-java/include/llvm/Java:

BytecodeParser.h updated: 1.10 -> 1.11
---
Log message:

Change interface of BytecodeParser::parse() method. It now takes a
start and end bytecode index.


---
Diffs of the changes:  (+7 -7)

Index: llvm-java/include/llvm/Java/BytecodeParser.h
diff -u llvm-java/include/llvm/Java/BytecodeParser.h:1.10 llvm-java/include/llvm/Java/BytecodeParser.h:1.11
--- llvm-java/include/llvm/Java/BytecodeParser.h:1.10	Mon Oct 11 16:51:24 2004
+++ llvm-java/include/llvm/Java/BytecodeParser.h	Mon Oct 18 11:23:03 2004
@@ -35,14 +35,14 @@
   protected:
 #define THIS ((SubClass*)this)
 
-    /// @brief parse code pointed to by \c code of size \c size
+    /// @brief parse code pointed to by \c code beginning at \c start
+    /// bytecode and ending at \c end bytecode
     ///
-    /// This function parses the code pointed to by \c code and
-    /// calls the subclass's do_<bytecode> method
-    /// appropriately. When this function returns all code up to
-    /// \c size is parsed.
-    void parse(const uint8_t* code, unsigned size) {
-      for (unsigned i = 0; i < size; ++i) {
+    /// This function parses the code pointed to by \c code and calls
+    /// the subclass's do_<bytecode> method appropriately. When this
+    /// function returns all code in [start, end) is parsed.
+    void parse(const uint8_t* code, unsigned start, unsigned end) {
+      for (unsigned i = start; i < end; ++i) {
         unsigned curBC = i;
         bool wide = code[i] == WIDE;
         i += wide;






More information about the llvm-commits mailing list